@@ -3,7 +3,7 @@
 #include "image.h"
 
 static const nv_image_t rotation_orientation_horiz_flipped_image = {
-  120, 90, 3,
+  120, 90, 3, 0,
   "\377\0\0\0\363\0\0\0\2\2\16\2\27\233\27\216\37\315\37\2\34\237>\26""9\353"
   "\340\25""5\375\2\20(\277\1\4\21\204\0\0\0\1\40\240\40\220*\324*\1'\255S\341"
   "\34F\375\1\25""5\277\204\0\0\0\2224\3334\342$X\375\204\0\0\0\222>\342>\1"
